# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "",
    "Also available in:": "Også tilgjengelig på:",
    "Archive": "Arkiv",
    "Categories": "Kategorier",
    "Comments": "",
    "LANGUAGE": "norsk",
    "Languages:": "",
    "More posts about %s": "Flere innlegg om %s",
    "Newer posts": "Nyere innlegg",
    "Next post": "Neste innlegg",
    "No posts found.": "",
    "Nothing found.": "",
    "Older posts": "Eldre innlegg",
    "Original site": "Opprinnelig side",
    "Posted:": "Publisert:",
    "Posts about %s": "Innlegg om %s",
    "Posts for year %s": "Innlegg fra %s",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "Innlegg fra {month} {year}",
    "Previous post": "Forrige innlegg",
    "Publication date": "",
    "RSS feed": "",
    "Read in English": "Les på norsk",
    "Read more": "Les mer",
    "Skip to main content": "",
    "Source": "Kilde",
    "Tags and Categories": "Merker og kategorier",
    "Tags": "Merker",
    "old posts, page %d": "eldre innlegg, side %d",
    "page %d": "side %d",
}
